<?php

/**
 * This field handler aggregates operations that can be done on a subscriber
 * under a single field providing a more flexible way to present them in a view.
 */
class newsletter_subscriber_handler_subscriber_operations_field extends views_handler_field {
  /**
   * Register additional fields needed for links construction.
   */
  function construct() {
    parent::construct();

    $this->additional_fields['subscriber_id'] = 'subscriber_id';
    $this->additional_fields['type'] = 'type';
  }

  /**
   * Add additional fields.
   */
  function query() {
    $this->ensure_my_table();
    $this->add_additional_fields();
  }

  /**
   * Render newsletter subscriber administration links.
   */
  function render($values) {
    $links = array();

    foreach (array('clone' => t('clone'), 'edit' => t('edit'), 'delete' => t('delete')) as $action => $text) {
      $type = $values->{$this->aliases['type']};

      //Creating a dummy subscriber to check access against
      $dummy_subscriber = (object) array('type' => $type);
      if (!newsletter_subscriber_access($action, $dummy_subscriber)) {
        continue;
      }
      $subscriber_id = $values->{$this->aliases['subscriber_id']};

      $links[] = array(
        'title' => $text,
        'href' => 'admin/config/media/newsletter/subscribers/manage/' . $subscriber_id . '/' . $action,
      );
    }

    if ($links) {
      return theme('links', array('links' => $links, 'attributes' => array('class' => array('links', 'inline', 'operations'))));
    }
  }
}
