<?php

/**
 * @file
 * Views integration for newsletter_subscriber module.
 */


/**
 * Implements hook_views_data_alter()
 */
function newsletter_subscriber_views_data_alter(&$data) {
  // Add user relationship.
  $data['newsletter_subscriber']['uid']['relationship'] = array(
    'handler' => 'views_handler_relationship',
    'base' => 'users',
    'base field' => 'uid',
    'label' => t('User'),
  );
  // Add administration links.
  $data['newsletter_subscriber']['operations'] = array(
    'field' => array(
      'title' => t('Operations links'),
      'help' => t('Display all operations available for this subscriber.'),
      'handler' => 'newsletter_subscriber_handler_subscriber_operations_field',
    ),
  );
}


/**
 * Implements hook_views_default_views().
 */
function newsletter_subscriber_views_default_views() {
  $view = new view;
  $view->name = 'newsletter_subscribers';
  $view->description = 'Display a list of subscribers for newsletter admins.';
  $view->tag = 'newsletter';
  $view->base_table = 'newsletter_subscriber';
  $view->human_name = 'Newsletter subscribers';
  $view->core = 7;
  $view->api_version = '3.0';
  $view->disabled = FALSE; /* Edit this to true to make a default view disabled initially */

  /* Display: Master */
  $handler = $view->new_display('default', 'Master', 'default');
  $handler->display->display_options['title'] = 'Subscribers';
  $handler->display->display_options['access']['type'] = 'perm';
  $handler->display->display_options['access']['perm'] = 'administer newsletter subscribers';
  $handler->display->display_options['cache']['type'] = 'none';
  $handler->display->display_options['query']['type'] = 'views_query';
  $handler->display->display_options['query']['options']['query_comment'] = FALSE;
  $handler->display->display_options['exposed_form']['type'] = 'basic';
  $handler->display->display_options['pager']['type'] = 'full';
  $handler->display->display_options['pager']['options']['items_per_page'] = '50';
  $handler->display->display_options['style_plugin'] = 'table';
  $handler->display->display_options['style_options']['columns'] = array(
    'subscriber_id' => 'subscriber_id',
    'mail' => 'mail',
    'status' => 'status',
    'confirmation_timestamp' => 'confirmation_timestamp',
    'name' => 'name',
    'title' => 'title',
  );
  $handler->display->display_options['style_options']['default'] = 'subscriber_id';
  $handler->display->display_options['style_options']['info'] = array(
    'subscriber_id' => array(
      'sortable' => 1,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'mail' => array(
      'sortable' => 1,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'status' => array(
      'sortable' => 1,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'confirmation_timestamp' => array(
      'sortable' => 1,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 1,
    ),
    'name' => array(
      'sortable' => 1,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
    'title' => array(
      'sortable' => 0,
      'default_sort_order' => 'asc',
      'align' => '',
      'separator' => '',
      'empty_column' => 0,
    ),
  );
  $handler->display->display_options['style_options']['override'] = 1;
  $handler->display->display_options['style_options']['sticky'] = 1;
  $handler->display->display_options['style_options']['empty_table'] = 1;
  /* Relationship: Entity Reference: Referenced Entity */
  $handler->display->display_options['relationships']['field_newsletter_list_target_id']['id'] = 'field_newsletter_list_target_id';
  $handler->display->display_options['relationships']['field_newsletter_list_target_id']['table'] = 'field_data_field_newsletter_list';
  $handler->display->display_options['relationships']['field_newsletter_list_target_id']['field'] = 'field_newsletter_list_target_id';
  $handler->display->display_options['relationships']['field_newsletter_list_target_id']['label'] = 'Subscribed lists';
  $handler->display->display_options['relationships']['field_newsletter_list_target_id']['required'] = 0;
  /* Relationship: Newsletter subscriber: Uid */
  $handler->display->display_options['relationships']['uid']['id'] = 'uid';
  $handler->display->display_options['relationships']['uid']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['relationships']['uid']['field'] = 'uid';
  $handler->display->display_options['relationships']['uid']['required'] = 0;
  /* Field: Newsletter subscriber: Newsletter subscriber ID */
  $handler->display->display_options['fields']['subscriber_id']['id'] = 'subscriber_id';
  $handler->display->display_options['fields']['subscriber_id']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['fields']['subscriber_id']['field'] = 'subscriber_id';
  $handler->display->display_options['fields']['subscriber_id']['label'] = 'ID';
  $handler->display->display_options['fields']['subscriber_id']['alter']['alter_text'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['make_link'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['absolute'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['external'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['replace_spaces'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['trim_whitespace'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['nl2br'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['word_boundary'] = 1;
  $handler->display->display_options['fields']['subscriber_id']['alter']['ellipsis'] = 1;
  $handler->display->display_options['fields']['subscriber_id']['alter']['more_link'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['strip_tags'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['trim'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['alter']['html'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['element_label_colon'] = 1;
  $handler->display->display_options['fields']['subscriber_id']['element_default_classes'] = 1;
  $handler->display->display_options['fields']['subscriber_id']['hide_empty'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['empty_zero'] = 0;
  $handler->display->display_options['fields']['subscriber_id']['hide_alter_empty'] = 1;
  $handler->display->display_options['fields']['subscriber_id']['format_plural'] = 0;
  /* Field: Newsletter subscriber: Mail */
  $handler->display->display_options['fields']['mail']['id'] = 'mail';
  $handler->display->display_options['fields']['mail']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['fields']['mail']['field'] = 'mail';
  $handler->display->display_options['fields']['mail']['alter']['alter_text'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['make_link'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['absolute'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['external'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['replace_spaces'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['trim_whitespace'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['nl2br'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['word_boundary'] = 1;
  $handler->display->display_options['fields']['mail']['alter']['ellipsis'] = 1;
  $handler->display->display_options['fields']['mail']['alter']['more_link'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['strip_tags'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['trim'] = 0;
  $handler->display->display_options['fields']['mail']['alter']['html'] = 0;
  $handler->display->display_options['fields']['mail']['element_label_colon'] = 1;
  $handler->display->display_options['fields']['mail']['element_default_classes'] = 1;
  $handler->display->display_options['fields']['mail']['hide_empty'] = 0;
  $handler->display->display_options['fields']['mail']['empty_zero'] = 0;
  $handler->display->display_options['fields']['mail']['hide_alter_empty'] = 1;
  /* Field: Newsletter subscriber: Type */
  $handler->display->display_options['fields']['type']['id'] = 'type';
  $handler->display->display_options['fields']['type']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['fields']['type']['field'] = 'type';
  $handler->display->display_options['fields']['type']['alter']['alter_text'] = 0;
  $handler->display->display_options['fields']['type']['alter']['make_link'] = 0;
  $handler->display->display_options['fields']['type']['alter']['absolute'] = 0;
  $handler->display->display_options['fields']['type']['alter']['external'] = 0;
  $handler->display->display_options['fields']['type']['alter']['replace_spaces'] = 0;
  $handler->display->display_options['fields']['type']['alter']['trim_whitespace'] = 0;
  $handler->display->display_options['fields']['type']['alter']['nl2br'] = 0;
  $handler->display->display_options['fields']['type']['alter']['word_boundary'] = 1;
  $handler->display->display_options['fields']['type']['alter']['ellipsis'] = 1;
  $handler->display->display_options['fields']['type']['alter']['more_link'] = 0;
  $handler->display->display_options['fields']['type']['alter']['strip_tags'] = 0;
  $handler->display->display_options['fields']['type']['alter']['trim'] = 0;
  $handler->display->display_options['fields']['type']['alter']['html'] = 0;
  $handler->display->display_options['fields']['type']['element_label_colon'] = 1;
  $handler->display->display_options['fields']['type']['element_default_classes'] = 1;
  $handler->display->display_options['fields']['type']['hide_empty'] = 0;
  $handler->display->display_options['fields']['type']['empty_zero'] = 0;
  $handler->display->display_options['fields']['type']['hide_alter_empty'] = 1;
  $handler->display->display_options['fields']['type']['machine_name'] = 0;
  /* Field: Newsletter subscriber: Status */
  $handler->display->display_options['fields']['status']['id'] = 'status';
  $handler->display->display_options['fields']['status']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['fields']['status']['field'] = 'status';
  $handler->display->display_options['fields']['status']['label'] = 'Active';
  $handler->display->display_options['fields']['status']['alter']['alter_text'] = 0;
  $handler->display->display_options['fields']['status']['alter']['make_link'] = 0;
  $handler->display->display_options['fields']['status']['alter']['absolute'] = 0;
  $handler->display->display_options['fields']['status']['alter']['external'] = 0;
  $handler->display->display_options['fields']['status']['alter']['replace_spaces'] = 0;
  $handler->display->display_options['fields']['status']['alter']['trim_whitespace'] = 0;
  $handler->display->display_options['fields']['status']['alter']['nl2br'] = 0;
  $handler->display->display_options['fields']['status']['alter']['word_boundary'] = 1;
  $handler->display->display_options['fields']['status']['alter']['ellipsis'] = 1;
  $handler->display->display_options['fields']['status']['alter']['more_link'] = 0;
  $handler->display->display_options['fields']['status']['alter']['strip_tags'] = 0;
  $handler->display->display_options['fields']['status']['alter']['trim'] = 0;
  $handler->display->display_options['fields']['status']['alter']['html'] = 0;
  $handler->display->display_options['fields']['status']['element_label_colon'] = 1;
  $handler->display->display_options['fields']['status']['element_default_classes'] = 1;
  $handler->display->display_options['fields']['status']['hide_empty'] = 0;
  $handler->display->display_options['fields']['status']['empty_zero'] = 0;
  $handler->display->display_options['fields']['status']['hide_alter_empty'] = 1;
  $handler->display->display_options['fields']['status']['type'] = 'unicode-yes-no';
  $handler->display->display_options['fields']['status']['not'] = 0;
  /* Field: Newsletter subscriber: Confirmation_timestamp */
  $handler->display->display_options['fields']['confirmation_timestamp']['id'] = 'confirmation_timestamp';
  $handler->display->display_options['fields']['confirmation_timestamp']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['fields']['confirmation_timestamp']['field'] = 'confirmation_timestamp';
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['alter_text'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['make_link'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['absolute'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['external'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['replace_spaces'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['trim_whitespace'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['nl2br'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['word_boundary'] = 1;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['ellipsis'] = 1;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['more_link'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['strip_tags'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['trim'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['alter']['html'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['element_label_colon'] = 1;
  $handler->display->display_options['fields']['confirmation_timestamp']['element_default_classes'] = 1;
  $handler->display->display_options['fields']['confirmation_timestamp']['hide_empty'] = 1;
  $handler->display->display_options['fields']['confirmation_timestamp']['empty_zero'] = 0;
  $handler->display->display_options['fields']['confirmation_timestamp']['hide_alter_empty'] = 1;
  /* Field: User: Name */
  $handler->display->display_options['fields']['name']['id'] = 'name';
  $handler->display->display_options['fields']['name']['table'] = 'users';
  $handler->display->display_options['fields']['name']['field'] = 'name';
  $handler->display->display_options['fields']['name']['relationship'] = 'uid';
  $handler->display->display_options['fields']['name']['label'] = 'Username';
  $handler->display->display_options['fields']['name']['alter']['alter_text'] = 0;
  $handler->display->display_options['fields']['name']['alter']['make_link'] = 0;
  $handler->display->display_options['fields']['name']['alter']['absolute'] = 0;
  $handler->display->display_options['fields']['name']['alter']['external'] = 0;
  $handler->display->display_options['fields']['name']['alter']['replace_spaces'] = 0;
  $handler->display->display_options['fields']['name']['alter']['trim_whitespace'] = 0;
  $handler->display->display_options['fields']['name']['alter']['nl2br'] = 0;
  $handler->display->display_options['fields']['name']['alter']['word_boundary'] = 1;
  $handler->display->display_options['fields']['name']['alter']['ellipsis'] = 1;
  $handler->display->display_options['fields']['name']['alter']['more_link'] = 0;
  $handler->display->display_options['fields']['name']['alter']['strip_tags'] = 0;
  $handler->display->display_options['fields']['name']['alter']['trim'] = 0;
  $handler->display->display_options['fields']['name']['alter']['html'] = 0;
  $handler->display->display_options['fields']['name']['element_label_colon'] = 1;
  $handler->display->display_options['fields']['name']['element_default_classes'] = 1;
  $handler->display->display_options['fields']['name']['hide_empty'] = 0;
  $handler->display->display_options['fields']['name']['empty_zero'] = 0;
  $handler->display->display_options['fields']['name']['hide_alter_empty'] = 1;
  $handler->display->display_options['fields']['name']['link_to_user'] = 1;
  $handler->display->display_options['fields']['name']['overwrite_anonymous'] = 0;
  $handler->display->display_options['fields']['name']['format_username'] = 1;
  /* Field: Newsletter subscriber: Operations links */
  $handler->display->display_options['fields']['operations']['id'] = 'operations';
  $handler->display->display_options['fields']['operations']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['fields']['operations']['field'] = 'operations';
  $handler->display->display_options['fields']['operations']['label'] = 'Operations';
  $handler->display->display_options['fields']['operations']['alter']['alter_text'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['make_link'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['absolute'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['external'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['replace_spaces'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['trim_whitespace'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['nl2br'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['word_boundary'] = 1;
  $handler->display->display_options['fields']['operations']['alter']['ellipsis'] = 1;
  $handler->display->display_options['fields']['operations']['alter']['more_link'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['strip_tags'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['trim'] = 0;
  $handler->display->display_options['fields']['operations']['alter']['html'] = 0;
  $handler->display->display_options['fields']['operations']['element_label_colon'] = 1;
  $handler->display->display_options['fields']['operations']['element_default_classes'] = 1;
  $handler->display->display_options['fields']['operations']['hide_empty'] = 0;
  $handler->display->display_options['fields']['operations']['empty_zero'] = 0;
  $handler->display->display_options['fields']['operations']['hide_alter_empty'] = 1;
  /* Filter criterion: Newsletter subscriber: Mail */
  $handler->display->display_options['filters']['mail']['id'] = 'mail';
  $handler->display->display_options['filters']['mail']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['filters']['mail']['field'] = 'mail';
  $handler->display->display_options['filters']['mail']['operator'] = 'contains';
  $handler->display->display_options['filters']['mail']['exposed'] = TRUE;
  $handler->display->display_options['filters']['mail']['expose']['operator_id'] = 'mail_op';
  $handler->display->display_options['filters']['mail']['expose']['label'] = 'E-mail';
  $handler->display->display_options['filters']['mail']['expose']['operator'] = 'mail_op';
  $handler->display->display_options['filters']['mail']['expose']['identifier'] = 'mail';
  $handler->display->display_options['filters']['mail']['expose']['required'] = 0;
  $handler->display->display_options['filters']['mail']['expose']['multiple'] = FALSE;
  /* Filter criterion: Newsletter subscriber: Type */
  $handler->display->display_options['filters']['type']['id'] = 'type';
  $handler->display->display_options['filters']['type']['table'] = 'newsletter_subscriber';
  $handler->display->display_options['filters']['type']['field'] = 'type';
  $handler->display->display_options['filters']['type']['exposed'] = TRUE;
  $handler->display->display_options['filters']['type']['expose']['operator_id'] = 'type_op';
  $handler->display->display_options['filters']['type']['expose']['label'] = 'Type';
  $handler->display->display_options['filters']['type']['expose']['operator'] = 'type_op';
  $handler->display->display_options['filters']['type']['expose']['identifier'] = 'type';
  $handler->display->display_options['filters']['type']['expose']['reduce'] = 0;

  /* Display: Page */
  $handler = $view->new_display('page', 'Page', 'page');
  $handler->display->display_options['path'] = 'admin/config/media/newsletter/subscribers/list';
  $handler->display->display_options['menu']['type'] = 'default tab';
  $handler->display->display_options['menu']['title'] = 'List';
  $handler->display->display_options['menu']['weight'] = '0';
  $handler->display->display_options['menu']['name'] = 'management';
  $handler->display->display_options['menu']['context'] = 0;
  $handler->display->display_options['tab_options']['type'] = 'normal';
  $handler->display->display_options['tab_options']['title'] = 'Subscribers';
  $handler->display->display_options['tab_options']['description'] = 'Manage newsletter subscribers.';
  $handler->display->display_options['tab_options']['weight'] = '0';
  $handler->display->display_options['tab_options']['name'] = 'management';

  $views[$view->name] = $view;
  return $views;
}
